import{d as f,ey as u,F as b,b as y,u as g,bu as _}from"./registerWidgets.2d3a9fa1.js";import{a as w}from"./asyncComputed.da67dddd.js";import"./gateway.90839648.js";import{M as s}from"./member.04f21a82.js";import"./index.cc19b71e.js";import{C as I}from"./CrudView.a779dd60.js";import"./passwordlessManager.7fdb47fd.js";import"./pubsub.f5cc447b.js";import"./storage.2f9edc3d.js";import"./activeRecord.85525a95.js";import"./DropdownMenu.1c4bd517.js";import"./Modal.0a34e3f8.js";import"./LoadingIndicator.25e4e865.js";import"./lottie.8f8e4fb5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f42dd9cf-e9c6-4ff4-b747-a5b1d106783d",e._sentryDebugIdIdentifier="sentry-dbid-f42dd9cf-e9c6-4ff4-b747-a5b1d106783d")}catch{}})();const N=f({__name:"Members",setup(e){const a=u().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(a,t.email),c()},{loading:d,result:l,refetch:c}=w(()=>s.list(a)),p=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=l.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{N as default};
//# sourceMappingURL=Members.7a73f634.js.map
