import{t,b as s,c}from"./registerWidgets.2d3a9fa1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="6e2c9d27-0bbf-4ceb-82b3-1c598c218232",e._sentryDebugIdIdentifier="sentry-dbid-6e2c9d27-0bbf-4ceb-82b3-1c598c218232")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.a66027f0.js.map
