import{S as c}from"./Sidebar.d0d1a467.js";import{N as m}from"./Navbar.6386a2d1.js";import{C as d,D as p,E as l}from"./icons.ef35efa7.js";import{d as u,ey as b,F as _,a as g,b as f,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.2d3a9fa1.js";import{a as h}from"./asyncComputed.da67dddd.js";import"./gateway.90839648.js";import{O as I}from"./organization.f163a5e9.js";import"./index.cc19b71e.js";import"./Tooltip.92b318c3.js";import"./logo.084e5d7c.js";import"./passwordlessManager.7fdb47fd.js";import"./pubsub.f5cc447b.js";import"./storage.2f9edc3d.js";import"./activeRecord.85525a95.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="dcdc1ee0-a87f-4251-8701-19ba1e4c599b",e._sentryDebugIdIdentifier="sentry-dbid-dcdc1ee0-a87f-4251-8701-19ba1e4c599b")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=b().params.organizationId,{result:o}=h(()=>I.get(n)),r=_(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=g("router-view");return f(),v(z,null,[t(m,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const G=w(D,[["__scopeId","data-v-51ce7239"]]);export{G as default};
//# sourceMappingURL=Organization.7bc12a7c.js.map
