import{u as a}from"./icons.ef35efa7.js";import{d as c,a as r,b as i,c as d,e as _,bu as l,bh as u,t as p}from"./registerWidgets.2d3a9fa1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="402b966e-ad39-413e-9c03-ec0467c85519",e._sentryDebugIdIdentifier="sentry-dbid-402b966e-ad39-413e-9c03-ec0467c85519")}catch{}})();const f=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=p(f,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.9f23fa5d.js.map
