import{d,r as f,o as l,eM as u,b as c,c as b,eA as p,eR as y}from"./registerWidgets.2d3a9fa1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1bca0987-6f33-4f81-8878-ee1122ebea54",e._sentryDebugIdIdentifier="sentry-dbid-1bca0987-6f33-4f81-8878-ee1122ebea54")}catch{}})();const g=d({__name:"ActionButton",props:{action:{}},emits:["next"],setup(e,{emit:n}){const o=e,s=f(null);l(()=>{s.value&&o.action.setElement(s.value),u.addAction(o.action)});const a=()=>n("next");return(r,t)=>(c(),b("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>a()),onKeydown:t[1]||(t[1]=y(i=>a(),["enter"]))},p(r.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.d48002ff.js.map
