import{P as n}from"./Passwordless.f47b04f0.js";import{d as r,ex as i,b as d,c,e as s,eq as _,t as m}from"./registerWidgets.2d3a9fa1.js";import{M as f}from"./member.04f21a82.js";import{W as p}from"./WidgetsFrame.c6f4d7d9.js";import"./CircularLoading.7f8cdc69.js";import"./lottie.8f8e4fb5.js";import"./icons.ef35efa7.js";import"./passwordlessManager.7fdb47fd.js";import"./pubsub.f5cc447b.js";import"./storage.2f9edc3d.js";import"./gateway.90839648.js";import"./activeRecord.85525a95.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="79fb2312-146d-4294-a2a6-5af9d986caba",e._sentryDebugIdIdentifier="sentry-dbid-79fb2312-146d-4294-a2a6-5af9d986caba")}catch{}})();const l={class:"login"},u=r({__name:"Login",setup(e){const o=i();async function t(a){await f.login(),o.push({name:"home"})}return(a,b)=>(d(),c("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(n,{class:"passwordless",onDone:t})]),_:1})]))}});const C=m(u,[["__scopeId","data-v-0e3dc783"]]);export{C as default};
//# sourceMappingURL=Login.d1e2f3c5.js.map
