import{M as r}from"./Modal.0a34e3f8.js";import{d as a,E as d,r as c,a as _,b as f,c as l,e as n,eq as i,bw as m,er as u,t as p}from"./registerWidgets.2d3a9fa1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ec13d4d9-6180-4073-942f-65cd1f76290a",e._sentryDebugIdIdentifier="sentry-dbid-ec13d4d9-6180-4073-942f-65cd1f76290a")}catch{}})();const y=["src"],b=a({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=c(null);return(g,w)=>{const s=_("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,y)]),_:1},512)],64)}}});const x=p(b,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.ff0169a8.js.map
