import{t as r,a,b as i,u as c,f as d,g as p,_,h as u,k as l,T as h,P as f,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.2d3a9fa1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2168f557-2852-4e2d-a562-91757cead0d2",e._sentryDebugIdIdentifier="sentry-dbid-2168f557-2852-4e2d-a562-91757cead0d2")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.8a6474a3.js"),["assets/Player.8a6474a3.js","assets/index.1a3a4850.js","assets/registerWidgets.2d3a9fa1.js","assets/registerWidgets.56192442.css","assets/uuid.b1ea1ffc.js","assets/broker.2019863b.js","assets/passwordlessManager.7fdb47fd.js","assets/pubsub.f5cc447b.js","assets/storage.2f9edc3d.js","assets/Passwordless.f47b04f0.js","assets/CircularLoading.7f8cdc69.js","assets/lottie.8f8e4fb5.js","assets/CircularLoading.f81b57b4.css","assets/icons.ef35efa7.js","assets/Passwordless.86ac0c56.css","assets/executeJs.76e35dd0.js","assets/PlayerNavbar.fdd6bac1.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.27fe6056.js","assets/Steps.998aa76d.css","assets/Modal.0a34e3f8.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.c6f4d7d9.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.d48002ff.js","assets/broker.95c7aa9a.css","assets/DashPlayer.2612053a.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.da67dddd.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(o),e.use(f),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.f525a044.js.map
